==> photo_editor_sdk-0.5.3.tar.gz: example/lib/main.dart <==
import 'package:flutter/material.dart';
import 'package:image_picker/image_picker.dart';
import 'package:photo_editor_sdk/photo_editor_sdk.dart';
import 'dart:async';

void main() => runApp(MyApp());

class MyApp extends StatefulWidget {
  @override
  _MyAppState createState() => _MyAppState();
}

class _MyAppState extends State<MyApp> {
  Image image;

  @override
  void initState() {
    super.initState();
    _loadEditor();
  }

  _loadEditor() async {
    PhotoEditorSdk.setUserId(id: "5dbbf86f318f9f0001399d4e");
    PhotoEditorSdk.setEditorOptions(options: [
      "logo",
      "sticker",
      "text",
      "brush",
      "frame",
      "transform",
      "textDesign",
      "adjust",
      "filter"
    ]);
    PhotoEditorSdk.addAllContents(
      stickers: [
        "https://encrypted-tbn0.gstatic.com/images?q=tbn%3AANd9GcRqMKspUMJsK9fQsQJEHgmQx1U8IOTs5HP0vgbVfZqynEo6-IIm",
        "https://encrypted-tbn0.gstatic.com/images?q=tbn%3AANd9GcS0uCtvg269jcaKa2P2AyYcrw5h-DRJR0Lpe2by9I5LZu15GBZN",
        "https://encrypted-tbn0.gstatic.com/images?q=tbn%3AANd9GcSS0zCE8uqmkD1DaSLuaXxYpJSuatSOyWdkaFhafZe-z8RKC6Kk",
      ],
      logos: [
        "https://encrypted-tbn0.gstatic.com/images?q=tbn%3AANd9GcQN5h7AhxdwNgR1hanAFyV4VA87ujSDaGpJymSwLQHJEMl573l6",
        "https://encrypted-tbn0.gstatic.com/images?q=tbn%3AANd9GcRw1jedDvieNuFQeXEKXp4F_ny9X1QFGU5HlZbB61nUliyxyy5Y",
        "https://pt.freelogodesign.org/Content/img/logo-samples/bakary.png"
      ],
    );
  }

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      home: Scaffold(
        appBar: AppBar(
          title: const Text('Plugin example app'),
        ),
        body: Center(
          child: Column(
            children: <Widget>[
              if (image != null) ...[image],
              RaisedButton(
                child: Text('Open editor'),
                onPressed: () async {
                  getImage();
                },
              ),
            ],
          ),
        ),
      ),
    );
  }

  Future getImage() async {
    // var image2 = await ImagePicker.pickImage(source: ImageSource.gallery);
    // PhotoEditorSdk.hasAddLogo();
    // await PhotoEditorSdk.editImage(image2.path, isLocally: true).then((r) {
    //   setState(() {
    //     image = Image.memory(r);
    //   });
    // });
    var pathUrl =
        "https://img.ahazou.com/ahz-posts/883944b2-3ff4-462d-8d02-b70e42c74b15/midia/post-ba27d295-df05-4ff9-a395-f8400c553b65.jpeg";
    var data =
        "https://storage.googleapis.com/ahz-midia-editables/0266b4cf-ad22-40b9-92e3-123e822681f8/editable/post-cbb52e8c-f963-416d-a2bf-4941b52c4802.json";
    await PhotoEditorSdk.editImageSerialized(
            pathUrl: pathUrl, jsonSerialized: data)
        .then((r) {
      setState(() {
        image = Image.memory(r);
      });
    });
  }
}

==> photo_editor_sdk-0.5.4.tar.gz: example/lib/main.dart <==
import 'package:flutter/material.dart';
import 'package:image_picker/image_picker.dart';
import 'package:photo_editor_sdk/photo_editor_sdk.dart';
import 'dart:async';

void main() => runApp(MyApp());

class MyApp extends StatefulWidget {
  @override
  _MyAppState createState() => _MyAppState();
}

class _MyAppState extends State<MyApp> {
  Image image;

  @override
  void initState() {
    super.initState();
    _loadEditor();
  }

  _loadEditor() async {
    PhotoEditorSdk.setUserId(id: "5dbbf86f318f9f0001399d4e");
    PhotoEditorSdk.setEditorOptions(options: [
      "logo",
      "sticker",
      "text",
      "brush",
      "frame",
      "transform",
      "textDesign",
      "adjust",
      "filter"
    ]);
    PhotoEditorSdk.addAllContents(
      stickers: [
        "https://encrypted-tbn0.gstatic.com/images?q=tbn%3AANd9GcRqMKspUMJsK9fQsQJEHgmQx1U8IOTs5HP0vgbVfZqynEo6-IIm",
        "https://encrypted-tbn0.gstatic.com/images?q=tbn%3AANd9GcS0uCtvg269jcaKa2P2AyYcrw5h-DRJR0Lpe2by9I5LZu15GBZN",
        "https://encrypted-tbn0.gstatic.com/images?q=tbn%3AANd9GcSS0zCE8uqmkD1DaSLuaXxYpJSuatSOyWdkaFhafZe-z8RKC6Kk",
      ],
      logos: [
        "https://encrypted-tbn0.gstatic.com/images?q=tbn%3AANd9GcQN5h7AhxdwNgR1hanAFyV4VA87ujSDaGpJymSwLQHJEMl573l6",
        "https://encrypted-tbn0.gstatic.com/images?q=tbn%3AANd9GcRw1jedDvieNuFQeXEKXp4F_ny9X1QFGU5HlZbB61nUliyxyy5Y",
        "https://pt.freelogodesign.org/Content/img/logo-samples/bakary.png"
      ],
    );
  }

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      home: Scaffold(
        appBar: AppBar(
          title: const Text('Plugin example app'),
        ),
        body: Center(
          child: Column(
            children: <Widget>[
              if (image != null) ...[image],
              RaisedButton(
                child: Text('Open editor'),
                onPressed: () async {
                  getImage();
                },
              ),
            ],
          ),
        ),
      ),
    );
  }

  Future getImage() async {
    // var image2 = await ImagePicker.pickImage(source: ImageSource.gallery);
    // PhotoEditorSdk.hasAddLogo();
    // await PhotoEditorSdk.editImage(image2.path, isLocally: true).then((r) {
    //   setState(() {
    //     image = Image.memory(r);
    //   });
    // });
    var pathUrl =
        "https://img.ahazou.com/ahz-posts/883944b2-3ff4-462d-8d02-b70e42c74b15/midia/post-ba27d295-df05-4ff9-a395-f8400c553b65.jpeg";
    var data = "https://storage.googleapis.com/ahz-midia-editables/0266b4cf-ad22-40b9-92e3-123e822681f8/editable/post-cbb52e8c-f963-416d-a2bf-4941b52c4802.json";
    await PhotoEditorSdk.editImageSerialized(
            pathUrl: pathUrl, jsonSerialized: data)
        .then((r) {
      setState(() {
        image = Image.memory(r);
      });
    });
  }
}
